@@ -126,7 +126,7 @@ class CacheWorkspace:
     """Manage a cache workspace on the cluster"""
 
     def __init__(self, path_to_exe: str = '/usr/bin/',
-                 name: str = 'cache', expire_in_days: int = 1) -> None:
+                 id: str = 'cache', expire_in_days: int = 1) -> None:
         '''Allocate a workspace on the cluster where we can store temporary files.
 
         If the workspace already exists, it is automatically reused.
@@ -135,15 +135,16 @@ class CacheWorkspace:
         ----------
         path_to_exe : str, optional
             path to the ws_* executables, by default '/usr/bin/'
-        name : str, optional
-            The name of the workspace. On the filesystem, it will be called something like /scratch/ws/0/username-name , by default 'cache'
+        id : str, optional
+            The id of the workspace. On the filesystem, it will be called something like /scratch/ws/0/username-id , by default 'cache'
         expire_in_days : int, optional
             this determines the number of tays until the workspace automatically expires, by default 1
         '''
         self.ws = Workspace(path_to_exe=path_to_exe)
-        self.name = name
+        self.id = id
         self.expire_in_days = expire_in_days
-        self.cache_dir = self._mk_cache()
+        self.name = None
+        self._mk_cache()
 
     def _mk_cache(self) -> str:
         '''Allocate a workspace on the cluster
@@ -153,16 +154,22 @@ class CacheWorkspace:
         str
             path to allocated workspace
         '''
-        res = subprocess.run(
-            [str(self.path_to_exe / 'ws_allocate'), self.name, str(self.expire_in_days), '-c', 'temporary_files'], capture_output=True)
-        return res.stdout.strip()
+        out, err = waitfor(
+            self.ws.ws_allocate(
+                self.id,
+                str(self.expire_in_days),
+                '-c',
+                'temporary_files'),
+            discard_output=False)
+        self.name = out.strip()
 
     def cleanup(self) -> None:
         '''release the allocated workspace.
 
         Files will be deleted automatically one day after release.
         '''
-        self.ws.ws_release(self.name)
+        waitfor(self.ws.ws_release(self.id))
+        self.name = None
 
 
 class CacheWorkspaceContext(CacheWorkspace):
@@ -170,27 +177,27 @@ class CacheWorkspaceContext(CacheWorkspace):
     '''
 
     def __init__(self, path_to_exe: str = '/usr/bin/',
-                 name: str = 'cache') -> None:
+                 id: str = 'cache') -> None:
         '''Create a context manager for a cache workspace.
 
         Parameters
         ----------
         path_to_exe : str, optional
             path to the ws_* executables, by default '/usr/bin/'
-        name : str, optional
-            name of the workspace to be used as cache, by default "cache"
+        id : str, optional
+            id of the workspace to be used as cache, by default "cache"
         '''
         self.ws = Workspace(path_to_exe=path_to_exe)
-        self.name = name
+        self.id = id
         self.expire_in_days = 1
-        self.cache_dir = None
+        self.name = None
 
     def __enter__(self) -> None:
-        if self.cache_dir is None:
-            self.cache_dir = self._mk_cache()
+        if self.name is None:
+            self._mk_cache()
 
     def __exit__(self, exception_type, exception_value, traceback) -> None:
-        if self.cache_dir is not None:
+        if self.name is not None:
             self.cleanup()
 
 
